# Contributing to Kopf

**Thank you for your interest in Kopf. Your contributions are highly welcome.**

There are multiple ways of getting involved:

- [Report a bug](#report-a-bug) 
- [Suggest a feature](#suggest-a-feature) 
- [Contribute code](#contribute-code) 

Below are a few guidelines we would like you to follow.
If you need help, please reach out to us by opening an issue.


## Report a bug 

Reporting bugs is one of the best ways to contribute. Before creating a bug report, please check that an [issue](/issues) reporting the same problem does not already exist. If there is such an issue, you may add your information as a comment.

To report a new bug you should open an issue that summarizes the bug and set the label to "bug".

If you want to provide a fix along with your bug report: That is great! In this case please send us a pull request as described in section [Contribute Code](#contribute-code).


## Suggest a feature

To request a new feature you should open an [issue](../../issues/new) and summarize the desired functionality and its use case. Set the issue label to "feature".  


## Contribute code

Check the list of open [issues](../../issues).
Either assign an existing issue to yourself, or create a new one
that you would like work on and discuss your ideas and use cases. 
It is always best to discuss your plans beforehand, 
to ensure that your contribution is in line with our goals.

Read https://kopf.readthedocs.io/en/stable/contributing/
for detailed information, conventions and guidelines.

Thanks for your contributions!

**Have fun, and happy hacking!**
